cgexplore.utilities
===================

.. automodule:: cgexplore.utilities

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: class.rst
      :nosignatures:
   
      AtomliteDatabase
      Pymol
   
   


   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
      :nosignatures:
   
      add_structure_to_ax
      add_text_to_ax
      check_directory
      convert_pyramid_angle
      draw_pie
      extract_property
      get_supramolecule
      get_unforced_supramolecule
      optimise_ligand
      run_constrained_optimisation
      run_optimisation
      run_soft_md_cycle
      shift_beads
      soften_forcefield
      write_chemiscope_json
      yield_near_models
      yield_shifted_models
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
      :toctree:
   
      ForceFieldUnavailableError
      ForceFieldUnitError
   
   



